Object.defineProperty(exports, "__esModule", { value: true });
/** Mitt: Tiny (~200b) functional event emitter / pubsub.
 *  @name mitt
 *  @returns {Mitt}
 */
var mitt = function mitt(events) {
    this._events = events || Object.create(null);
};
/**
 * Register an event handler for the given type.
 *
 * @param  {String} type	Type of event to listen for, or `"*"` for all events
 * @param  {Function} handler Function to call in response to given event
 * @memberOf mitt
 */
mitt.prototype.on = function on (type, handler) {
    (this._events[type] || (this._events[type] = [])).push(handler);
};
/**
 * Remove an event handler for the given type.
 *
 * @param  {String} type	Type of event to unregister `handler` from, or `"*"`
 * @param  {Function} handler Handler function to remove
 * @memberOf mitt
 */
mitt.prototype.off = function off (type, handler) {
    if (this._events[type]) {
        this._events[type].splice(this._events[type].indexOf(handler) >>> 0, 1);
    }
};
/**
 * Invoke this.all handlers for the given type.
 * If present, `"*"` handlers are invoked after type-matched handlers.
 *
 * Note: Manually firing "*" handlers is not supported.
 *
 * @param {String} type  The event type to invoke
 * @param {Any} [evt]  Any value (object is recommended and powerful), passed to each handler
 * @memberOf mitt
 */
mitt.prototype.emit = function emit (type, evt) {
    (this._events[type] || []).slice().map(function (handler) {
        handler(evt);
    });
    (this._events['*'] || []).slice().map(function (handler) {
        handler(type, evt);
    });
};
exports.default = mitt;
//# sourceMappingURL=cjs.js.map
